@@ -5,4 +5,4 @@
 #define QT_FEATURE_wayland_datadevice 1
 #define QT_FEATURE_wayland_egl 1
 #define QT_FEATURE_xcomposite_egl 1
-#define QT_FEATURE_xcomposite_glx -1
+#define QT_FEATURE_xcomposite_glx 1
